@@ -4,6 +4,7 @@ from requests.auth import HTTPBasicAuth
 
 from py42.exceptions import Py42Error
 from py42.exceptions import Py42UnauthorizedError
+from py42.services._auth import ApiClientAuth
 from py42.services._auth import BearerAuth
 from py42.services._auth import CustomJWTAuth
 from py42.services._connection import Connection
@@ -13,6 +14,23 @@ warnings.simplefilter("always", DeprecationWarning)
 warnings.simplefilter("always", UserWarning)
 
 
+def from_api_client(host_address, client_id, secret):
+    """Creates a :class:`~py42.sdk.SDKClient` object for accessing the Code42 REST APIs using
+    an API client ID and secret.
+
+    Args:
+        host_address (str): The domain name of the Code42 instance being authenticated to, e.g.
+            console.us.code42.com
+        client_id (str): The client ID of the API client to authenticate with.
+        secret (str): The secret of the API client to authenticate with.
+
+    Returns:
+        :class:`py42.sdk.SDKClient`
+    """
+
+    return SDKClient.from_api_client(host_address, client_id, secret)
+
+
 def from_local_account(host_address, username, password, totp=None):
     """Creates a :class:`~py42.sdk.SDKClient` object for accessing the Code42 REST APIs using the
     supplied credentials. This method supports only accounts created within the Code42 console or using the
@@ -65,10 +83,35 @@ def from_jwt_provider(host_address, jwt_provider):
 
 
 class SDKClient:
-    def __init__(self, main_connection, auth):
-        services, user_ctx = _init_services(main_connection, auth)
+    def __init__(self, main_connection, auth, auth_flag=None):
+        services, user_ctx = _init_services(main_connection, auth, auth_flag)
         self._clients = _init_clients(services, main_connection)
         self._user_ctx = user_ctx
+        self._auth_flag = auth_flag
+
+    @classmethod
+    def from_api_client(cls, host_address, client_id, secret):
+        """Creates a :class:`~py42.sdk.SDKClient` object for accessing the Code42 REST APIs using
+        an API client ID and secret.
+
+        Args:
+            host_address (str): The domain name of the Code42 instance being authenticated to, e.g.
+                console.us.code42.com
+            client_id (str): The client ID of the API client to authenticate with.
+            secret (str): The secret of the API client to authenticate with.
+
+        Returns:
+            :class:`py42.sdk.SDKClient`
+        """
+
+        basic_auth = HTTPBasicAuth(client_id, secret)
+        auth_connection = Connection.from_host_address(host_address, auth=basic_auth)
+        api_client_auth = ApiClientAuth(auth_connection)
+        main_connection = Connection.from_host_address(
+            host_address, auth=api_client_auth
+        )
+        api_client_auth.get_credentials()
+        return cls(main_connection, api_client_auth, auth_flag=1)
 
     @classmethod
     def from_local_account(cls, host_address, username, password, totp=None):
@@ -113,7 +156,7 @@ class SDKClient:
         """
         custom_auth = CustomJWTAuth(jwt_provider)
         main_connection = Connection.from_host_address(host_address, auth=custom_auth)
-
+        custom_auth.get_credentials()
         return cls(main_connection, custom_auth)
 
     @property
@@ -207,16 +250,6 @@ class SDKClient:
         """
         return self._clients.securitydata
 
-    @property
-    def detectionlists(self):
-        """A collection of properties each containing methods for managing specific detection
-        lists, such as departing employees.
-
-        Returns:
-            :class:`py42.clients.detectionlists.DetectionListsClient`
-        """
-        return self._clients.detectionlists
-
     @property
     def alerts(self):
         """A collection of methods related to retrieving and updating alerts rules.
@@ -273,7 +306,7 @@ class SDKClient:
         return self._clients.watchlists
 
 
-def _init_services(main_connection, main_auth):
+def _init_services(main_connection, main_auth, auth_flag=None):
     # services are imported within function to prevent circular imports when a service
     # imports anything from py42.sdk.queries
     from py42.services import Services
@@ -285,12 +318,10 @@ def _init_services(main_connection, main_auth):
     from py42.services.auditlogs import AuditLogsService
     from py42.services.cases import CasesService
     from py42.services.casesfileevents import CasesFileEventsService
-    from py42.services.detectionlists.departing_employee import DepartingEmployeeService
-    from py42.services.detectionlists.high_risk_employee import HighRiskEmployeeService
-    from py42.services.detectionlists.user_profile import DetectionListUserService
     from py42.services.devices import DeviceService
     from py42.services.fileevent import FileEventService
     from py42.services.legalhold import LegalHoldService
+    from py42.services.legalholdapiclient import LegalHoldApiClientService
     from py42.services.orgs import OrgService
     from py42.services.preservationdata import PreservationDataService
     from py42.services.savedsearch import SavedSearchService
@@ -303,7 +334,6 @@ def _init_services(main_connection, main_auth):
     alerts_key = "AlertService-API_URL"
     file_events_key = "FORENSIC_SEARCH-API_URL"
     preservation_data_key = "PRESERVATION-DATA-SERVICE_API-URL"
-    employee_case_mgmt_key = "employeecasemanagementV2-API_URL"
     kv_prefix = "simple-key-value-store"
     audit_logs_key = "AUDIT-LOG_API-URL"
     cases_key = "CASES_API-URL"
@@ -325,17 +355,12 @@ def _init_services(main_connection, main_auth):
     pds_conn = Connection.from_microservice_key(
         kv_service, preservation_data_key, auth=main_auth
     )
-    ecm_conn = Connection.from_microservice_key(
-        kv_service, employee_case_mgmt_key, auth=main_auth
-    )
     audit_logs_conn = Connection.from_microservice_key(
         kv_service, audit_logs_key, auth=main_auth
     )
-    user_svc = UserService(main_connection)
     administration_svc = AdministrationService(main_connection)
     file_event_svc = FileEventService(file_events_conn)
     user_ctx = UserContext(administration_svc)
-    user_profile_svc = DetectionListUserService(ecm_conn, user_ctx, user_svc)
     cases_conn = Connection.from_microservice_key(kv_service, cases_key, auth=main_auth)
     trusted_activities_conn = Connection.from_microservice_key(
         kv_service, trusted_activities_key, auth=main_auth
@@ -343,29 +368,28 @@ def _init_services(main_connection, main_auth):
     watchlists_conn = Connection.from_microservice_key(
         kv_service, watchlists_key, auth=main_auth
     )
+    user_risk_profile_svc = UserRiskProfileService(watchlists_conn)
 
     services = Services(
         administration=administration_svc,
         archive=ArchiveService(main_connection),
         devices=DeviceService(main_connection),
-        legalhold=LegalHoldService(main_connection),
+        # Only use updated legal hold client if initialized with API Client authorization
+        legalhold=LegalHoldApiClientService(main_connection)
+        if auth_flag
+        else LegalHoldService(main_connection),
         orgs=OrgService(main_connection),
         users=UserService(main_connection),
-        alertrules=AlertRulesService(alert_rules_conn, user_ctx, user_profile_svc),
+        alertrules=AlertRulesService(alert_rules_conn, user_ctx, user_risk_profile_svc),
         alerts=AlertService(alerts_conn, user_ctx),
         fileevents=file_event_svc,
         savedsearch=SavedSearchService(file_events_conn, file_event_svc),
         preservationdata=PreservationDataService(pds_conn),
-        departingemployee=DepartingEmployeeService(
-            ecm_conn, user_ctx, user_profile_svc
-        ),
-        highriskemployee=HighRiskEmployeeService(ecm_conn, user_ctx, user_profile_svc),
-        userprofile=user_profile_svc,
         auditlogs=AuditLogsService(audit_logs_conn),
         cases=CasesService(cases_conn),
         casesfileevents=CasesFileEventsService(cases_conn),
         trustedactivities=TrustedActivitiesService(trusted_activities_conn),
-        userriskprofile=UserRiskProfileService(watchlists_conn),
+        userriskprofile=user_risk_profile_svc,
         watchlists=WatchlistsService(watchlists_conn),
     )
 
@@ -383,11 +407,9 @@ def _init_clients(services, connection):
     from py42.clients.auditlogs import AuditLogsClient
     from py42.clients.authority import AuthorityClient
     from py42.clients.cases import CasesClient
-    from py42.clients.detectionlists import DetectionListsClient
     from py42.clients.loginconfig import LoginConfigurationClient
     from py42.clients.securitydata import SecurityDataClient
     from py42.clients.trustedactivities import TrustedActivitiesClient
-    from py42.services.storage._service_factory import ConnectionManager
     from py42.services.storage._service_factory import StorageServiceFactory
     from py42.clients.userriskprofile import UserRiskProfileClient
     from py42.clients.watchlists import WatchlistsClient
@@ -400,12 +422,7 @@ def _init_clients(services, connection):
         orgs=services.orgs,
         users=services.users,
     )
-    detectionlists = DetectionListsClient(
-        services.userprofile, services.departingemployee, services.highriskemployee
-    )
-    storage_service_factory = StorageServiceFactory(
-        connection, services.devices, ConnectionManager()
-    )
+    storage_service_factory = StorageServiceFactory(connection, services.devices)
     alertrules = AlertRulesClient(services.alerts, services.alertrules)
     securitydata = SecurityDataClient(
         services.fileevents,
@@ -421,11 +438,10 @@ def _init_clients(services, connection):
     auditlogs = AuditLogsClient(services.auditlogs)
     loginconfig = LoginConfigurationClient(connection)
     trustedactivities = TrustedActivitiesClient(services.trustedactivities)
-    userriskprofile = UserRiskProfileClient(services.userriskprofile)
+    userriskprofile = UserRiskProfileClient(services.userriskprofile, services.users)
     watchlists = WatchlistsClient(services.watchlists)
     clients = Clients(
         authority=authority,
-        detectionlists=detectionlists,
         alerts=alerts,
         securitydata=securitydata,
         archive=archive,
