@@ -30,9 +30,6 @@ Services = namedtuple(
         "fileevents",
         "savedsearch",
         "preservationdata",
-        "departingemployee",
-        "highriskemployee",
-        "userprofile",
         "auditlogs",
         "cases",
         "casesfileevents",
