@@ -43,6 +43,18 @@ class BearerAuth(C42RenewableAuth):
         return f"Bearer {response['v3_user_token']}"
 
 
+class ApiClientAuth(C42RenewableAuth):
+    def __init__(self, auth_connnection):
+        super().__init__()
+        self._auth_connection = auth_connnection
+
+    def _get_credentials(self):
+        uri = "/api/v3/oauth/token"
+        params = {"grant_type": "client_credentials"}
+        response = self._auth_connection.post(uri, params=params)
+        return f"Bearer {response['access_token']}"
+
+
 class CustomJWTAuth(C42RenewableAuth):
     def __init__(self, jwt_provider):
         super().__init__()
