@@ -2,6 +2,8 @@ from py42.exceptions import Py42InvalidRuleError
 from py42.exceptions import Py42NotFoundError
 from py42.services import BaseService
 
+# Incydr functionality is deprecated as of 2025-03.
+
 
 class AlertRulesService(BaseService):
     """A service to manage Alert Rules."""
@@ -42,7 +44,7 @@ class AlertRulesService(BaseService):
     def add_user(self, rule_id, user_id):
         tenant_id = self._user_context.get_current_tenant_id()
         user_details = self._user_profile_service.get_by_id(user_id)
-        user_aliases = user_details.data.get("cloudUsernames") or []
+        user_aliases = user_details.data.get("cloudAliases") or []
         data = {
             "tenantId": tenant_id,
             "ruleId": rule_id,
